@@ -2,7 +2,7 @@
 coxaalen.control <- function(eps = 1e-7, eps.norm = c("max", "grad"),
                                iter.max = 5000, armijo = 1/3, var.coef = TRUE,
                                coef.typ = 1, coef.max = 10, trace = FALSE,
-                               thread.max = 1)
+                               thread.max = 1, data = FALSE)
 {
   eps.norm <- match.arg(eps.norm)
   if (eps <= .Machine$double.eps)
@@ -19,5 +19,5 @@ coxaalen.control <- function(eps = 1e-7, eps.norm = c("max", "grad"),
     stop("Invalid scale for Armijo's rule. Choose a value in (0, 1/2).")
   list(eps = eps, eps.norm = eps.norm, iter.max = iter.max, armijo = armijo,
        var.coef = var.coef, coef.typ = coef.typ, coef.max = coef.max,
-       trace = trace, thread.max = thread.max)
+       trace = trace, thread.max = thread.max, data = data)
 }
