@@ -1,5 +1,5 @@
 ### maximal intersections from an interval-type Surv object
-maximalint <- function(x)
+maximalint <- function(x, eps = 1e-7)
 {
   if (is.null(nrow(x))) x <- matrix(x, nrow = 1)
   if (ncol(x) == 2) x[is.na(x[, 2]), 2] <- Inf
@@ -14,20 +14,12 @@ maximalint <- function(x)
   if (sum(!ind)) {
     l <- unique(x[!ind, 1])
     r <- r.minus <- unique(x[!ind, 2])
-    if (max(l, r[r < Inf]) <= 2) delta <- .Machine$double.eps
-    else {
-      s <- sort(unique(c(l, r)))
-      if (length(s) > 1)
-        delta <- min(s[-1] - s[-length(s)]) / 10
-      else
-        delta <- s / 10
-    }
-    r.minus[r %in% l] <- r[r %in% l] - delta
+    r.minus[r %in% l] <- r[r %in% l] - eps
   }
   else l <- r <- r.minus <- NULL
   if (sum(ind)) {
     ## open left-endpoint
-    x[ind, 1] <- x[ind, 2] - .Machine$double.eps
+    x[ind, 1] <- x[ind, 2] - eps
     l <- c(l, unique(x[ind, 1]))
     r.minus <- c(r.minus, unique(x[ind, 2]))
     r <- c(r, unique(x[ind, 2]))
@@ -38,6 +30,7 @@ maximalint <- function(x)
   ## maximal intersection left endpoint, right endpoint without and with ties 
   s <- s[s[, 3] == 0 & s[, 6] == 1, c(1, 4, 5)]
   if (is.null(nrow(s))) s <- matrix(s, nrow = 1)
+  colnames(s) <- c("left", "right.untied", "right")
   ## maximal intersection overlap with censoring interval indicator matrix
   if (nrow(s) < 2) i <- matrix(1)
   else
