@@ -7,8 +7,8 @@ print.coxinterval <- function(x, ...)
   on.exit(options(saved.digits))
   est <- x$coef
   se <- sqrt(diag(x$var))
-  mat <- cbind(est, se, est/se, 1 - pchisq((est/se)^2, 1), exp(est))
-  dimnames(mat) <- list(names(est), c("coef", "se(coef)", "z", "p", "exp(coef)"))
+  mat <- cbind(est, exp(est), se, est/se, 1 - pchisq((est/se)^2, 1))
+  dimnames(mat) <- list(names(est), c("coef", "exp(coef)", "se(coef)", "z", "p"))
   cat("\n")
   if (x$p > 0) prmatrix(mat)
   else cat("Null model\n")
